# projectkiwi

Tools to interact with project-kiwi.org


### Installation
```Bash
pip install projectkiwi
```


### Getting Started

See further documentation here: [Read The Docs](https://projectkiwi.readthedocs.io/en/latest/user_manual/getting_started.html)